"""
from checkout import Payment
from checkout import Payments
from django.http import HttpResponse
from django.template import loader
from django.views.decorators.csrf import csrf_exempt
from django.views.generic import TemplateView

from shopping_app import PropertiesFileReader


# disabling csrf (cross site request forgery)
class PaymentsResource(TemplateView):
    #print('PaymentsResource')
    @csrf_exempt
    def retrieve_payments(self, request):
        try:
            if request.method == 'GET':

                partner_id = PropertiesFileReader.properties[PropertiesFileReader.CHECKOUT_CLIENT_ID]
                client_sig_key = PropertiesFileReader.properties[PropertiesFileReader.CLIENT_SIG_KEY]

                if 'ext_cust_id' in request.session and request.session['ext_cust_id']:
                    customer_id = request.session['ext_cust_id']
                else:
                    customer_id = 'sai@example.com'

                customer_payments_response = None
                error_message = None
                try:
                    customer_payments_response = Payments().for_customer(customer_id).for_partner(partner_id=partner_id,
                                                                                                  signature_key=client_sig_key).retrieve()
                except BaseException as e:
                    print ('exception ', e)
                    error_message = 'Something went wrong. Please try again later.'

                print ('customerPaymentsResponse: ', customer_payments_response)
                print ('error_message: ', error_message)
                context = {
                    'customerPaymentsResponse': customer_payments_response,
                    'error_message': error_message
                }
                template = loader.get_template('payments.html')
                return HttpResponse(template.render(context, request))
            else:
                template = loader.get_template('404.html')
                return HttpResponse(template.render(None, request))
        except BaseException as e:
            print ('exception ', e)
            template = loader.get_template('error.html')
            return HttpResponse(template.render(None, request))

    @csrf_exempt
    def retrieve_payment_details(self, request, payment_id):
        try:
            if request.method == 'GET':
                print ('payment_id: ', payment_id)
                partner_id = PropertiesFileReader.properties[PropertiesFileReader.CHECKOUT_CLIENT_ID]
                client_sig_key = PropertiesFileReader.properties[PropertiesFileReader.CLIENT_SIG_KEY]

                payment_details_response = None
                error_message = None
                try:
                    payment_details_response = Payment().for_partner(partner_id=partner_id,
                                                                     signature_key=client_sig_key).retrieve(
                        payment_id)
                except BaseException as e:
                    print ('exception ', e)
                    error_message = 'Something went wrong. Please try again later.'

                print ('paymentDetailsResponse: ', payment_details_response)
                context = {
                    'paymentDetailsResponse': payment_details_response,
                    'error_message': error_message
                }
                template = loader.get_template('payment-details.html')
                return HttpResponse(template.render(context, request))
            else:
                template = loader.get_template('404.html')
                return HttpResponse(template.render(None, request))
        except BaseException as e:
            print ('exception ', e)
            template = loader.get_template('error_pop_up.html')
            return HttpResponse(template.render(None, request))

    @csrf_exempt
    def cancel_payment(self, request, payment_id):
        try:
            if request.method == 'GET':

                print ('payment_id: ', payment_id)
                partner_id = PropertiesFileReader.properties[PropertiesFileReader.CHECKOUT_CLIENT_ID]
                client_sig_key = PropertiesFileReader.properties[PropertiesFileReader.CLIENT_SIG_KEY]

                payment_details_response = None
                error_message = None
                try:
                    payment_details_response = Payment().for_partner(partner_id=partner_id,
                                                                     signature_key=client_sig_key).retrieve(
                        payment_id)
                except BaseException as e:
                    print ('exception ', e)
                    error_message = 'Something went wrong. Please try again later.'

                print ('paymentDetailsResponse: ', payment_details_response)
                context = {
                    'paymentDetailsResponse': payment_details_response,
                    'error_message': error_message
                }
                template = loader.get_template('cancel-payment-form.html')
                return HttpResponse(template.render(context, request))

            elif request.method == 'DELETE':

                print ('payment_id: ', payment_id)
                partner_id = PropertiesFileReader.properties[PropertiesFileReader.CHECKOUT_CLIENT_ID]
                client_sig_key = PropertiesFileReader.properties[PropertiesFileReader.CLIENT_SIG_KEY]

                cancel_payment_response = None
                error_message = None
                try:
                    cancel_payment_response = Payment().for_partner(partner_id=partner_id,
                                                                    signature_key=client_sig_key).cancel(
                        payment_id)
                except BaseException as e:
                    print ('exception ', e)
                    error_message = 'Something went wrong. Please try again later.'

                print ('cancel_payment_response: ', cancel_payment_response)
                context = {
                    'paymentId': payment_id,
                    'error_message': error_message
                }
                template = loader.get_template('cancel-payment-response.html')
                return HttpResponse(template.render(context, request))

            else:
                template = loader.get_template('404.html')
                return HttpResponse(template.render(None, request))
        except BaseException as e:
            print ('exception ', e)
            template = loader.get_template('error_pop_up.html')
            return HttpResponse(template.render(None, request))
"""
